@@ -1,23 +1,10 @@
 /*
   This file is part of the KDE Kontact Plugin Interface Library.
 
-  Copyright (c) 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
-  Copyright (c) 2002-2003 Daniel Molkentin <molkentin@kde.org>
+  SPDX-FileCopyrightText: 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
+  SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "plugin.h"
@@ -29,7 +16,7 @@
 #include <KXMLGUIFactory>
 #include <KAboutData>
 #include <KLocalizedString>
-#include <KRun>
+#include <KIO/CommandLauncherJob>
 
 #include <QObject>
 #include <QDBusConnection>
@@ -65,7 +52,7 @@ public:
     QString serviceName;
     QByteArray partLibraryName;
     QByteArray pluginName;
-    KParts::ReadOnlyPart *part = nullptr;
+    KParts::Part *part = nullptr;
     bool hasPart;
     bool disabled;
 };
@@ -140,7 +127,7 @@ bool Plugin::isRunningStandalone() const
     return false;
 }
 
-KParts::ReadOnlyPart *Plugin::loadPart()
+KParts::Part *Plugin::loadPart()
 {
     return core()->createPart(d->partLibraryName.constData());
 }
@@ -150,12 +137,12 @@ const KAboutData Plugin::aboutData()
     return part()->componentData();
 }
 
-KParts::ReadOnlyPart *Plugin::part()
+KParts::Part *Plugin::part()
 {
     if (!d->part) {
         d->part = createPart();
         if (d->part) {
-            connect(d->part, &KParts::ReadOnlyPart::destroyed, this, [this]() { d->partDestroyed(); });
+            connect(d->part, &KParts::Part::destroyed, this, [this]() { d->partDestroyed(); });
             d->removeInvisibleToolbarActions(this);
             core()->partLoaded(this, d->part);
         }
@@ -310,6 +297,9 @@ void Plugin::Private::removeInvisibleToolbarActions(Plugin *plugin)
 
 void Plugin::Private::setXmlFiles()
 {
+    if (pluginName.isEmpty()) {
+        return;
+    }
     const QString newAppFile =
         QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kontact/default-") + QLatin1String(pluginName) + QLatin1String(".rc");
     const QString localFile =
@@ -335,7 +325,8 @@ void Plugin::bringToForeground()
 #ifdef Q_OS_WIN
     activateWindowForProcess(d->executableName);
 #else
-    KRun::runCommand(d->executableName, nullptr);
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(d->executableName);
+    job->start();
 #endif
 }
 
